const electron      = require('electron');
const app           = electron.app;
const Menu          = electron.Menu;
const BrowserWindow = electron.BrowserWindow;
const path          = require("path");

const iolabWindow = require('./iolabWindow');
const repoWindow = require('./repoWindow');

const appName = 'IOLab';

var template = [
    {
        label: appName,
        submenu: [
            {
                label: 'About ' + appName,
                click: function () {
                    var cmd = 'IOLabEventHandler.sendEvent({ name: "openAboutModal"})';
                    iolabWindow.executeJavaScript(cmd);
                }
            },
            {
                type: 'separator'
            },
            {
                label: 'Hide ' + appName,
                accelerator: 'CmdOrCtrl+H',
                selector: 'hide:'
            },
            {
                label: 'Hide Others',
                accelerator: 'CmdOrCtrl+Shift+H',
                selector: 'hideOtherApplications:'
            },
            {
                label: 'Show All',
                selector: 'unhideAllApplications:'
            },
            {
                type: 'separator'
            },
            {
                label: 'Quit',
                accelerator: 'CmdOrCtrl+Q',
                click: function () {
                    app.quit();
                }
            }
        ]
    },
    {
        label: 'Edit',
        submenu: [
            {
                label: 'Cut',
                accelerator: 'CmdOrCtrl+X',
                selector: 'cut:'
            },
            {
                label: 'Copy',
                accelerator: 'CmdOrCtrl+C',
                selector: 'copy:'
            },
            {
                label: 'Paste',
                accelerator: 'CmdOrCtrl+V',
                selector: 'paste:'
            },
            {
                label: 'Select All',
                accelerator: 'CmdOrCtrl+A',
                selector: 'selectAll:'
            }
        ]
    },
    {
        label: 'View',
        submenu: [
            {
                label: 'Print',
                accelerator: 'CmdOrCtrl+P',
                click: function () {
                    BrowserWindow.getFocusedWindow().webContents.print();
                }
            },
            {
                type: 'separator'
            },
            {
                label: 'Clear cache',
                accelerator:  (function() {
                    if (process.platform === 'darwin')
                        return 'Alt+Command+C';
                    else
                        return 'Ctrl+Shift+C';
                })(),
                click: function () {
                    iolabWindow.clearCache();
                    repoWindow.clearCache();
                }
            },
            {
                label: 'Reload',
                accelerator: 'CmdOrCtrl+R',
                click: function () {
                    BrowserWindow.getFocusedWindow().reload();
                }
            },
            {
                label: 'Toggle DevTools',
                accelerator: (function() {
                    if (process.platform === 'darwin')
                        return 'Alt+Command+I';
                    else
                        return 'Ctrl+Shift+I';
                })(),
                click: function () {
                    BrowserWindow.getFocusedWindow().toggleDevTools();
                }
            }
        ]
    },
    {
        label: 'Window',
        submenu: [
            {
                label: 'Minimize',
                accelerator: 'CmdOrCtrl+M',
                selector: 'performMiniaturize:'
            },
            {
                label: 'Close',
                accelerator: 'CmdOrCtrl+W',
                selector: 'performClose:'
            },
            {
                type: 'separator'
            },
            {
                label: 'Bring All to Front',
                selector: 'arrangeInFront:'
            }
        ]
    }
];

module.exports = function applyTemplate() {
    Menu.setApplicationMenu(Menu.buildFromTemplate(template));
};
